Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(54)

Unified Diff: pkg/dartino_compiler/lib/src/hub/sentence_parser.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/dartino_compiler/lib/src/hub/sentence_parser.dart
diff --git a/pkg/fletchc/lib/src/hub/sentence_parser.dart b/pkg/dartino_compiler/lib/src/hub/sentence_parser.dart
similarity index 98%
rename from pkg/fletchc/lib/src/hub/sentence_parser.dart
rename to pkg/dartino_compiler/lib/src/hub/sentence_parser.dart
index 9f4d2f28885d67a61ea3878efc41b28ff3a3a424..60ee91a9dca4ffbb5ece64de7dcb9b5c0880f390 100644
--- a/pkg/fletchc/lib/src/hub/sentence_parser.dart
+++ b/pkg/dartino_compiler/lib/src/hub/sentence_parser.dart
@@ -2,7 +2,7 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE.md file.
-library fletchc.hub.sentence_parser;
+library dartino_compiler.hub.sentence_parser;
import 'dart:convert' show
JSON;
@@ -418,7 +418,7 @@ class ErrorTarget extends Target {
String toString() => "ErrorTarget($errorKind, ${quoteString(userInput)})";
}
/// A sentence is a written command to fletch. Normally, this command is
/// written on the command-line and should be easy to write without having
/// getting into conflict with Unix shell command line parsing.
///
@@ -418,7 +418,7 @@ class ErrorTarget extends Target {
String toString() => "ErrorTarget($errorKind, ${quoteString(userInput)})";
}
-/// A sentence is a written command to fletch. Normally, this command is
+/// A sentence is a written command to dartino. Normally, this command is
/// written on the command-line and should be easy to write without having
/// getting into conflict with Unix shell command line parsing.
« no previous file with comments | « pkg/dartino_compiler/lib/src/hub/hub_main.dart ('k') | pkg/dartino_compiler/lib/src/hub/session_manager.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698